@@ -2,7 +2,7 @@
 
 
 /**
-  * SquirrelMail Quick Save Plugin
+  * SquirrelMail Quicksave Plugin
   * Copyright (c) 2001-2002 Ray Black <allah@accessnode.net>
   * Copyright (c) 2003-2007 Paul Lesniewski <paul@squirrelmail.org>
   * Licensed under the GNU GPL. For full terms see the file COPYING.
@@ -58,7 +58,7 @@ function quicksave_check_configuration_do()
 
       // something went wrong
       //
-      do_err('Quick Save plugin requires the Compatibility plugin version 2.0.7+', FALSE);
+      do_err('Quicksave plugin requires the Compatibility plugin version 2.0.7+', FALSE);
       return TRUE;
 
    }
@@ -265,17 +265,13 @@ function quicksave_clear_do()
 
 
 
-//TODO: if SM core has $compose_messages purged, won't need qs_cancelled
-   global $quicksave_message_sent_status, $qs_cancelled, $username;
+   // now, deal with the message sent flag
+   //
+   global $quicksave_message_sent_status, $username;
    sqGetGlobalVar('quicksave_message_sent_status', $quicksave_message_sent_status, SQ_SESSION);
-//TODO: if SM core has $compose_messages purged, won't need qs_cancelled
-   sqGetGlobalVar('qs_cancelled', $qs_cancelled, SQ_FORM);
    $qs_username = preg_replace('/[\.@_]/', '', $username);
 
 
-
-   // now, deal with the message sent flag
-   //
    if (!empty($quicksave_message_sent_status) && $quicksave_message_sent_status == 'sent')
    {
 
@@ -316,22 +312,6 @@ function quicksave_clear_do()
 
    }
 
-
-   // and if Cancel button was clicked, clean up compose messages
-   //
-//TODO: if SM core has $compose_messages purged, won't need qs_cancelled and any of this here
-   else if (!empty($qs_cancelled) && $qs_cancelled == '1')
-   {
-      global $composesession, $compose_messages;
-      sqGetGlobalVar('composesession', $composesession, SQ_SESSION);
-      sqGetGlobalVar('compose_messages', $compose_messages, SQ_SESSION);
-      if (!empty($compose_messages[$composesession])) 
-      {
-         unset($compose_messages[$composesession]);
-         sqsession_register($compose_messages,'compose_messages');
-      }
-   }
-
 }
 
 
@@ -358,7 +338,6 @@ function quicksave_cancel_button_do()
 
    // if they're composing in a new window...
    //
-//FIXME: when just closing popup, there is no way to clean up SM composesession
    if ($compose_new_win == '1') 
       $quick_save_return_url = '::CLOSE::';
 
@@ -371,9 +350,7 @@ function quicksave_cancel_button_do()
                              . '?passed_id=' . (($forward_id > 0) ? $forward_id : $passed_id)
                              . '&startMessage=' . $startMessage
                              . '&mailbox=' . $urlMailbox
-                             . (isset($passed_ent_id) ? '&passed_ent_id=' . $passed_ent_id : '')
-//TODO: if SM core has $compose_messages purged, won't need qs_cancelled
-                             . '&qs_cancelled=1';
+                             . (isset($passed_ent_id) ? '&passed_ent_id=' . $passed_ent_id : '');
    }
 
 
@@ -385,9 +362,7 @@ function quicksave_cancel_button_do()
                              . '?passed_id=' . (($reply_id > 0) ? $reply_id : $passed_id)
                              . '&startMessage=' . $startMessage
                              . '&mailbox=' . $urlMailbox
-                             . (isset($passed_ent_id) ? '&passed_ent_id=' . $passed_ent_id : '')
-//TODO: if SM core has $compose_messages purged, won't need qs_cancelled
-                             . '&qs_cancelled=1';
+                             . (isset($passed_ent_id) ? '&passed_ent_id=' . $passed_ent_id : '');
    }
 
 
@@ -397,9 +372,7 @@ function quicksave_cancel_button_do()
    {
       $quick_save_return_url = 'right_main.php'
                              . '?startMessage=' . $startMessage
-                             . '&mailbox=' . $urlMailbox
-//TODO: if SM core has $compose_messages purged, won't need qs_cancelled
-                             . '&qs_cancelled=1';
+                             . '&mailbox=' . $urlMailbox;
    }
 
 
@@ -457,15 +430,11 @@ function quicksave_compose_functions_do()
 
    global $sigappend, $from_htmladdr_search, $restrict_senders_error_no_to_recipients,
           $restrict_senders_error_too_many_recipients, $compose_new_win, $mail_sent,
-          $restrict_senders_error_too_many_emails_today, $banned_possible_spammer,
-          $quicksave_message_sent_status, $censored;
+          $quicksave_message_sent_status;
    sqGetGlobalVar('sigappend', $sigappend, SQ_FORM);
    sqGetGlobalVar('from_htmladdr_search', $from_htmladdr_search, SQ_FORM);
    sqGetGlobalVar('restrict_senders_error_too_many_recipients', $restrict_senders_error_too_many_recipients, SQ_FORM);
    sqGetGlobalVar('restrict_senders_error_no_to_recipients', $restrict_senders_error_no_to_recipients, SQ_FORM);
-   sqgetGlobalVar('restrict_senders_error_too_many_emails_today', $restrict_senders_error_too_many_emails_today, SQ_FORM);
-   sqgetGlobalVar('banned_possible_spammer', $banned_possible_spammer, SQ_FORM);
-   sqgetGlobalVar('censored', $censored, SQ_FORM);
    sqGetGlobalVar('mail_sent', $mail_sent, SQ_FORM);
    sqGetGlobalVar('quicksave_message_sent_status', $quicksave_message_sent_status, SQ_SESSION);
 
@@ -482,9 +451,6 @@ function quicksave_compose_functions_do()
     && $from_htmladdr_search != 'true'
     && $restrict_senders_error_no_to_recipients != 1
     && $restrict_senders_error_too_many_recipients != 1
-    && $restrict_senders_error_too_many_emails_today != 1
-    && $banned_possible_spammer != 1
-    && $censored != 1
     && empty($_FILES['attachfile'])
 // NOTE: prior version of quicksave only did the following check if $compose_in_new is turned on or if $mail_sent is 'yes', but technically, if quicksave is working correctly, those are not useful... if this becomes a problem, they could be added back...
     && (empty($quicksave_message_sent_status) || $quicksave_message_sent_status != 'sent'))
@@ -496,11 +462,7 @@ function quicksave_compose_functions_do()
    {
       $offer_recovery_OK = FALSE;
       $quicksave_message_sent_status = 'not_sent';
-// the below causes PHP error in 1.5.2 until 1.5.2 is fixed so compose.php 
-// uses templates for all output; not sure if this happens in 1.4.x too...
-// plugin might work OK without this...?
-      if (!headers_sent())
-         sqsession_register($quicksave_message_sent_status, 'quicksave_message_sent_status');
+      sqsession_register($quicksave_message_sent_status, 'quicksave_message_sent_status');
    }
 
 
@@ -660,40 +622,6 @@ function quicksave_clear_storage()
 }
 
 
-// this function trims all whitespace from 
-// the front and end of a string
-//
-function trim(stringToTrim) 
-{
-
-   if (stringToTrim == null) return null;
-
-
-   // we could probably use the following, but the code below works 
-   // works with even older browsers (pre-version-4 generation)
-   //
-   //return stringToTrim.replace(/^\s+|\s+$/g,"");
-
- 
-   while (stringToTrim.charAt(0) == ' ' 
-       || stringToTrim.charAt(0) == '\\n' 
-       || stringToTrim.charAt(0) == '\\t' 
-       || stringToTrim.charAt(0) == '\\f' 
-       || stringToTrim.charAt(0) == '\\r')
-      stringToTrim = stringToTrim.substring(1, stringToTrim.length);
-
-   while (stringToTrim.charAt(stringToTrim.length - 1) == ' ' 
-       || stringToTrim.charAt(stringToTrim.length - 1) == '\\n' 
-       || stringToTrim.charAt(stringToTrim.length - 1) == '\\t' 
-       || stringToTrim.charAt(stringToTrim.length - 1) == '\\f' 
-       || stringToTrim.charAt(stringToTrim.length - 1) == '\\r')
-      stringToTrim = stringToTrim.substring(0, stringToTrim.length - 1);
-
-   return stringToTrim;
-
-}
-
-
 // this function saves the current to/cc/bcc/subject and mesasge body
 // in the quicksave message cache
 //
@@ -1318,7 +1246,7 @@ EOS;
       $confirm_recovery_string_pre = _("WARNING: The following email was interrupted and was never sent!");
       $to_string = _("To:");
       $subject_string = _("Subject:");
-      $confirm_recovery_string_post = _("Do you wish to resume it?  (Press cancel to discard message)");
+      $confirm_recovery_string_post = _("Do you wish to restore it?  (Press cancel to discard message)");
       $restored_string = _("Email restored!");
       $reminder_string = _("Please remember to press Send when finished typing your message.");
 
@@ -1332,11 +1260,11 @@ if (quicksave_get_from_cookie_unencrypted("is_active") == "1")
 
    // start restoration process
    //
-   var sendToCheck = trim(quicksave_get_from_cookie("send_to"));
-   var sendToCcCheck = trim(quicksave_get_from_cookie("send_to_cc"));
-   var sendToBccCheck = trim(quicksave_get_from_cookie("send_to_bcc"));
-   var subjectCheck = trim(quicksave_get_from_cookie("subject"));
-   var bodyCheck = trim(quicksave_get_from_cookie("body"));
+   var sendToCheck = quicksave_get_from_cookie("send_to");
+   var sendToCcCheck = quicksave_get_from_cookie("send_to_cc");
+   var sendToBccCheck = quicksave_get_from_cookie("send_to_bcc");
+   var subjectCheck = quicksave_get_from_cookie("subject");
+   var bodyCheck = quicksave_get_from_cookie("body");
 
 
    // format strings to be shown in alert popup
@@ -1365,18 +1293,10 @@ if (quicksave_get_from_cookie_unencrypted("is_active") == "1")
 
 EOS;
 
-      // at this point, we can short-cut directly to the 
-      // recovery if the right flag is given
-      //
-      if (sqGetGlobalVar('qs_recover', $qs_recover, SQ_FORM) && $qs_recover == 1)
-         $output .= "      // recover immediately, because qs_recover was specified in page request\n      //\n      quicksave_cookie_restore();\n      //alert('$restored_string\\n\\n$reminder_string');\n";
-
-      else
+      global $show_message_body_on_recover_notice;
+      if ($show_message_body_on_recover_notice)
       {
-         global $show_message_body_on_recover_notice;
-         if ($show_message_body_on_recover_notice)
-         {
-            $output .= <<<EOS
+         $output .= <<<EOS
       var showBody = new String(''+bodyCheck+'');
       if (showBody.length > 80)
          showBody = showBody.substr(0,75) + '...';
@@ -1385,13 +1305,13 @@ EOS;
       else
          showBody = '\\n\\n' + showBody;
 EOS;
-         }
-         else
-            $output .= "      var showBody = '';\n";
+      }
+      else
+         $output .= "      var showBody = '';\n";
 
       //if (confirm('$confirm_recovery_string_pre\\n\\n  $to_string ' + showTo.toString() + '\\n  $subject_string ' + showSub.toString() + '\\n\\n$confirm_recovery_string_post'))
 
-         $output .= <<<EOS
+      $output .= <<<EOS
       if (confirm('$confirm_recovery_string_pre\\n\\n  $to_string ' + showTo.toString() + '\\n  $subject_string ' + showSub.toString() + showBody + '\\n\\n$confirm_recovery_string_post'))
       {
          quicksave_cookie_restore();
@@ -1401,9 +1321,6 @@ EOS;
       {
          quicksave_clear_storage();
       }
-EOS;
-      }
-      $output .= <<<EOS
    }
    else 
    {
